ValueGrid

Struct ValueGrid 

pub struct ValueGrid<T: Value> { /* private fields */ }
A 2D grid of values.

The memory layout is the one the display expects in crate::Commands.

This structure can be used with any type that implements the Value trait. You can also use the concrete type aliases provided in this crate, e.g. crate::CharGrid and crate::ByteGrid.

Implementations

Source

impl ValueGrid<Brightness>

pub fn saturating_load(width: usize, height: usize, data: &[u8]) -> Option<Self>

Like Self::load, but ignoring any out-of-range brightness values

Source

impl ValueGrid<char>

pub fn wrap_str(width: usize, text: &str) -> Self

Loads a CharGrid with the specified width from the provided text, wrapping to as many rows as needed.

The passed rows are extended with ‘\0’ if needed.

returns: CharGrid that contains a copy of the provided data.

Examples
let grid = CharGrid::wrap_str(2, "abc\ndef");
Source

impl ValueGrid<u8>

pub fn load_ascii( value: &str, width: usize, wrap: bool, ) -> Result<Self, InvalidCharError>

Load an ASCII-only &str into a Cp437Grid of specified width.

Panics
  • for width == 0
  • on empty strings
Source

impl<T: Value> ValueGrid<T>

pub fn new(width: usize, height: usize) -> Self

Creates a new ValueGrid with the specified dimensions.

Arguments
  • width: size in x-direction
  • height: size in y-direction

returns: ValueGrid initialized to default value.

pub fn load(width: usize, height: usize, data: &[T]) -> Option<Self>

Loads a ValueGrid with the specified dimensions from the provided data.

returns: ValueGrid that contains a copy of the provided data, or None if the dimensions do not match the data size.

pub fn from_vec(width: usize, data: Vec<T>) -> Option<Self>

Creates a ValueGrid with the specified width from the provided data, wrapping to as many rows as needed, without copying the vec.

returns: ValueGrid that contains the provided data, or None if the data size is not divisible by the width.

Examples
let grid = ValueGrid::from_vec(2, vec![0, 1, 2, 3, 4, 5]).unwrap();
pub fn iter(&self) -> impl Iterator<Item = &T>

Iterate over all cells in ValueGrid.

Order is equivalent to the following loop:

for y in 0..grid.height() {
    for x in 0..grid.width() {
        grid.get(x, y);
    }
}
pub fn iter_rows(&self) -> impl Iterator<Item = Iter<'_, T>>

Iterate over all rows in ValueGrid top to bottom.

pub fn iter_mut(&mut self) -> IterMut<'_, T>

Returns an iterator that allows modifying each value.

The iterator yields all cells from top left to bottom right.

pub fn get_ref_mut(&mut self, x: usize, y: usize) -> &mut T

Get a mutable reference to the current value at the specified position.

Arguments
  • x and y: position of the cell
Panics

When accessing x or y out of bounds.

pub fn get_ref_mut_optional(&mut self, x: usize, y: usize) -> Option<&mut T>

Get a mutable reference to the current value at the specified position if position is in bounds.

Arguments
  • x and y: position of the cell

returns: Reference to cell or None

pub fn map<TConverted, F>(&self, f: F) -> ValueGrid<TConverted>
where TConverted: Value, F: Fn(T) -> TConverted,

Convert between ValueGrid types.

See also Iterator::map.

Examples

Use logic written for u8s and then convert to Brightness values for sending in a Command.

let mut grid: ByteGrid = ByteGrid::new(TILE_WIDTH, TILE_HEIGHT);
foo(&mut grid);
let grid: BrightnessGrid = grid.map(Brightness::saturating_from);
let command = BrightnessGridCommand { origin: Origin::ZERO, grid };
pub fn enumerate(&self) -> impl Iterator<Item = (usize, usize, T)> + use<'_, T>

Enumerates all values in the grid.

pub fn window( &self, xs: impl RangeBounds<usize>, ys: impl RangeBounds<usize>, ) -> Option<Window<'_, T, Self>>

Creates a window into the grid.

Returns None in case the window does not fit.

pub fn window_mut( &mut self, xs: impl RangeBounds<usize>, ys: impl RangeBounds<usize>, ) -> Option<WindowMut<'_, T, Self>>

Creates a mutable window into the grid.

Returns None in case the window does not fit.