Window

Struct Window 

pub struct Window<'t, TElement: Copy, TGrid: Grid<TElement>> { /* private fields */ }
A window into a 2D grid.

All operations are done directly on the contained reference, but translated to where the window is.

Implementations

Source

impl<'t, TElement: Copy, TGrid: Grid<TElement>> Window<'t, TElement, TGrid>

pub fn new( grid: &'t TGrid, xs: impl RangeBounds<usize>, ys: impl RangeBounds<usize>, ) -> Option<Self>

Create a new window into grid.

pub fn window( &self, xs: impl RangeBounds<usize>, ys: impl RangeBounds<usize>, ) -> Option<Window<'_, TElement, TGrid>>

Creates a window into the window.

Returns None in case the window does not fit.

pub fn split_horizontal( &'t self, left_width: usize, ) -> Option<(Window<'t, TElement, TGrid>, Window<'t, TElement, TGrid>)>

Splits the window horizontally, returning windows to the left and right parts.

The right window fills the remaining width, which may be zero.

Returns None for out-of-bounds.

pub fn split_vertical( &'t self, top_height: usize, ) -> Option<(Window<'t, TElement, TGrid>, Window<'t, TElement, TGrid>)>

Splits the window vertically, returning windows to the top and bottom parts.

The bottom window fills the remaining height, which may be zero.

Returns None for out-of-bounds.