pub struct WindowMut<'t, TElement: Copy, TGrid: Grid<TElement>> { /* private fields */ }Expand description
A window into a 2D grid.
All operations are done directly on the contained reference, but translated to where the window is.
Implementations
Sourceimpl<'t, TElement: Copy, TGrid: Grid<TElement>> WindowMut<'t, TElement, TGrid>
impl<'t, TElement: Copy, TGrid: Grid<TElement>> WindowMut<'t, TElement, TGrid>
Sourcepub fn new(
grid: &'t mut TGrid,
xs: impl RangeBounds<usize>,
ys: impl RangeBounds<usize>,
) -> Option<Self>
pub fn new( grid: &'t mut TGrid, xs: impl RangeBounds<usize>, ys: impl RangeBounds<usize>, ) -> Option<Self>
Create a new window into grid.
Sourcepub fn window(
&self,
xs: impl RangeBounds<usize>,
ys: impl RangeBounds<usize>,
) -> Option<Window<'_, TElement, TGrid>>
pub fn window( &self, xs: impl RangeBounds<usize>, ys: impl RangeBounds<usize>, ) -> Option<Window<'_, TElement, TGrid>>
Creates a window into the window.
Returns None in case the window does not fit.
Sourcepub fn split_horizontal(
&'t self,
left_width: usize,
) -> Option<(Window<'t, TElement, TGrid>, Window<'t, TElement, TGrid>)>
pub fn split_horizontal( &'t self, left_width: usize, ) -> Option<(Window<'t, TElement, TGrid>, Window<'t, TElement, TGrid>)>
Splits the window horizontally, returning windows to the left and right parts.
The right window fills the remaining width, which may be zero.
Returns None for out-of-bounds.
Sourcepub fn split_vertical(
&'t self,
top_height: usize,
) -> Option<(Window<'t, TElement, TGrid>, Window<'t, TElement, TGrid>)>
pub fn split_vertical( &'t self, top_height: usize, ) -> Option<(Window<'t, TElement, TGrid>, Window<'t, TElement, TGrid>)>
Splits the window vertically, returning windows to the top and bottom parts.
The bottom window fills the remaining height, which may be zero.
Returns None for out-of-bounds.
Sourceimpl<TElement: Copy, TGrid: GridMut<TElement>> WindowMut<'_, TElement, TGrid>
impl<TElement: Copy, TGrid: GridMut<TElement>> WindowMut<'_, TElement, TGrid>
Sourcepub fn window_mut(
&mut self,
xs: impl RangeBounds<usize>,
ys: impl RangeBounds<usize>,
) -> Option<WindowMut<'_, TElement, TGrid>>
pub fn window_mut( &mut self, xs: impl RangeBounds<usize>, ys: impl RangeBounds<usize>, ) -> Option<WindowMut<'_, TElement, TGrid>>
Creates a mutable window into the grid.
Returns None in case the window does not fit.
Sourcepub fn split_horizontal_mut<'t>(
&'t mut self,
left_width: usize,
) -> Option<(WindowMut<'t, TElement, TGrid>, WindowMut<'t, TElement, TGrid>)>
pub fn split_horizontal_mut<'t>( &'t mut self, left_width: usize, ) -> Option<(WindowMut<'t, TElement, TGrid>, WindowMut<'t, TElement, TGrid>)>
Splits the window horizontally, returning windows to the left and right parts.
The right window fills the remaining width, which may be zero.
Returns None for out-of-bounds.
Sourcepub fn split_vertical_mut<'t>(
&'t mut self,
top_height: usize,
) -> Option<(WindowMut<'t, TElement, TGrid>, WindowMut<'t, TElement, TGrid>)>
pub fn split_vertical_mut<'t>( &'t mut self, top_height: usize, ) -> Option<(WindowMut<'t, TElement, TGrid>, WindowMut<'t, TElement, TGrid>)>
Splits the window vertically, returning windows to the top and bottom parts.
The bottom window fills the remaining height, which may be zero.
Returns None for out-of-bounds.