pub struct ValueGrid<T: Value> { /* private fields */ }Expand description
A 2D grid of values.
The memory layout is the one the display expects in crate::Commands.
This structure can be used with any type that implements the Value trait.
You can also use the concrete type aliases provided in this crate, e.g. crate::CharGrid and crate::ByteGrid.
Implementations
Sourceimpl ValueGrid<Brightness>
impl ValueGrid<Brightness>
Sourcepub fn saturating_load(width: usize, height: usize, data: &[u8]) -> Option<Self>
pub fn saturating_load(width: usize, height: usize, data: &[u8]) -> Option<Self>
Like Self::load, but ignoring any out-of-range brightness values
Sourceimpl ValueGrid<u8>
impl ValueGrid<u8>
Sourcepub fn load_ascii(
value: &str,
width: usize,
wrap: bool,
) -> Result<Self, InvalidCharError>
pub fn load_ascii( value: &str, width: usize, wrap: bool, ) -> Result<Self, InvalidCharError>
Sourceimpl<T: Value> ValueGrid<T>
impl<T: Value> ValueGrid<T>
Sourcepub fn from_vec(width: usize, data: Vec<T>) -> Option<Self>
pub fn from_vec(width: usize, data: Vec<T>) -> Option<Self>
Creates a ValueGrid with the specified width from the provided data,
wrapping to as many rows as needed,
without copying the vec.
returns: ValueGrid that contains the provided data,
or None if the data size is not divisible by the width.
Examples
let grid = ValueGrid::from_vec(2, vec![0, 1, 2, 3, 4, 5]).unwrap();Sourcepub fn iter(&self) -> impl Iterator<Item = &T>
pub fn iter(&self) -> impl Iterator<Item = &T>
Iterate over all cells in ValueGrid.
Order is equivalent to the following loop:
for y in 0..grid.height() {
for x in 0..grid.width() {
grid.get(x, y);
}
}Sourcepub fn iter_rows(&self) -> impl Iterator<Item = Iter<'_, T>>
pub fn iter_rows(&self) -> impl Iterator<Item = Iter<'_, T>>
Iterate over all rows in ValueGrid top to bottom.
Sourcepub fn iter_mut(&mut self) -> IterMut<'_, T>
pub fn iter_mut(&mut self) -> IterMut<'_, T>
Returns an iterator that allows modifying each value.
The iterator yields all cells from top left to bottom right.
Sourcepub fn get_ref_mut(&mut self, x: usize, y: usize) -> &mut T
pub fn get_ref_mut(&mut self, x: usize, y: usize) -> &mut T
Sourcepub fn get_ref_mut_optional(&mut self, x: usize, y: usize) -> Option<&mut T>
pub fn get_ref_mut_optional(&mut self, x: usize, y: usize) -> Option<&mut T>
Get a mutable reference to the current value at the specified position if position is in bounds.
Arguments
xandy: position of the cell
returns: Reference to cell or None
Sourcepub fn map<TConverted, F>(&self, f: F) -> ValueGrid<TConverted>
pub fn map<TConverted, F>(&self, f: F) -> ValueGrid<TConverted>
Convert between ValueGrid types.
See also Iterator::map.
Examples
Use logic written for u8s and then convert to Brightness values for sending in a Command.
let mut grid: ByteGrid = ByteGrid::new(TILE_WIDTH, TILE_HEIGHT);
foo(&mut grid);
let grid: BrightnessGrid = grid.map(Brightness::saturating_from);
let command = BrightnessGridCommand { origin: Origin::ZERO, grid };Sourcepub fn enumerate(&self) -> impl Iterator<Item = (usize, usize, T)> + use<'_, T>
pub fn enumerate(&self) -> impl Iterator<Item = (usize, usize, T)> + use<'_, T>
Enumerates all values in the grid.
Sourcepub fn window(
&self,
xs: impl RangeBounds<usize>,
ys: impl RangeBounds<usize>,
) -> Option<Window<'_, T, Self>>
pub fn window( &self, xs: impl RangeBounds<usize>, ys: impl RangeBounds<usize>, ) -> Option<Window<'_, T, Self>>
Creates a window into the grid.
Returns None in case the window does not fit.
Sourcepub fn window_mut(
&mut self,
xs: impl RangeBounds<usize>,
ys: impl RangeBounds<usize>,
) -> Option<WindowMut<'_, T, Self>>
pub fn window_mut( &mut self, xs: impl RangeBounds<usize>, ys: impl RangeBounds<usize>, ) -> Option<WindowMut<'_, T, Self>>
Creates a mutable window into the grid.
Returns None in case the window does not fit.